#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or (at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright 2000-2005 Free Software Foundation
#
# DESCRIPTION:
# A wxPython based user interface driver for GNUe forms.
#
# NOTES:
#
# $Id: button.py 6851 2005-01-03 20:59:28Z jcater $

from wxPython.wx import *

from gnue.common import events
from gnue.forms.uidrivers.wx.common import _setDefaultEventHandlers
from gnue.forms.uidrivers.wx.common import _eventObjTowxWindow, wxEncode
from gnue.forms.uidrivers.wx.widgets._base import UIHelper

# =============================================================================
# Wrap an UI layer around a wxButton widget
# =============================================================================
class UIButton(UIHelper):
  """
  Creates a single instance of a button.
  """

  # --------------------------------------------------------------------------
  # Create a button widget
  # --------------------------------------------------------------------------
  def _createWidget(self, event, spacer):
    """
    Creates a new Button widget.
    """
    object = event.object

    itemX =      self.itemX
    itemY =      (object.Char__y + spacer) * event.widgetHeight
    itemWidth =  object.Char__width * event.widgetWidth
    if not hasattr (object, 'Char__height'):
      object.Char__height = 1

    itemHeight = object.Char__height * event.widgetHeight

    newWidget = wxButton(event.container, -1, wxEncode(object.label),
                         wxPoint(itemX, itemY), wxSize(itemWidth, itemHeight))

    if event.initialize:
      self._eventHandler = event.eventHandler
      EVT_BUTTON(newWidget, newWidget.GetId(), self.buttonHandler)
      _setDefaultEventHandlers(newWidget, event.eventHandler, event.initialize, self._uiDriver)

    return newWidget


  # --------------------------------------------------------------------------
  # Handle button clicks
  # --------------------------------------------------------------------------
  def buttonHandler(self, event):
    """
    Handle button clicks.
    """
    if event.GetEventType() == wxEVT_COMMAND_BUTTON_CLICKED:
      action = None
      object = _eventObjTowxWindow(event)
      id = object.GetId()
      gfObject = self._uiDriver._IdToGFObj[id]
      action = events.Event('buttonActivated', gfObject)
      self._eventHandler(action)


# ----------------------------------------------------------------------------
# Configuration data
# ----------------------------------------------------------------------------
configuration = {
    'baseClass'  : UIButton,
    'provides'   : 'GFButton',
    'container'  : 0,
    }
